Enum diem_config::network_id::NetworkId [−][src]
#[repr(u8)]
pub enum NetworkId {
Validator,
Vfn,
Public,
}Expand description
A representation of the network being used in communication.
There should only be one of each NetworkId used for a single node (except for NetworkId::Public),
and handshakes should verify that the NetworkId being used is the same during a handshake,
to effectively ensure communication is restricted to a network. Network should be checked that
it is not the DEFAULT_NETWORK
Variants
Implementations
Roles for a prioritization of relative upstreams
Roles for a prioritization of relative downstreams