Struct diem_config::network_id::NetworkContext [−][src]
pub struct NetworkContext { /* fields omitted */ }Expand description
A grouping of common information between all networking code for logging. This should greatly reduce the groupings between these given everywhere, and will allow for logging accordingly.
Implementations